==> nextcloud-app-deck-1%3A1.13.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/lv.js <==
OC.L10N.register(
    "deck",
    {
    "Load more" : "Ielādēt vairāk",
    "Personal" : "Personīgs",
    "Finished" : "Pabeigts",
    "Later" : "Vēlāk",
    "copy" : "kopēt",
    "Done" : "Pabeigts",
    "The file was uploaded" : "Datne tika augšupielādēta",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Augšupielādētā datne pārsniedz php.ini norādīto upload_max_filesize vērtību",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Augšupielādētā datne pārsniedz MAX_FILE_SIZE norādi, kas ir norādīta HTML formā",
    "The file was only partially uploaded" : "Datne tika augšupielādēta tikai daļēji",
    "No file was uploaded" : "Neviena datne netika augšupielādēta",
    "Missing a temporary folder" : "Trūkst pagaidu mapes",
    "Could not write file to disk" : "Nevarēja ierakstīt datni diskā",
    "A PHP extension stopped the file upload" : "PHP paplašinājums apturēja datnes augšupielādi",
    "Invalid date, date format must be YYYY-MM-DD" : "Nederīgs datums, datuma formātam jābūt YYYY-MM-DD",
    "Cancel" : "Atcelt",
    "File already exists" : "Datne jau pastāv",
    "Do you want to overwrite it?" : "Vai tu gribi pārrakstīt to?",
    "Open" : "Atvērt",
    "Completed" : "Pabeigts",
    "Hide archived cards" : "Slēpt arhivētās kartes",
    "Show archived cards" : "Rādīt arhivētās kartes",
    "Open details" : "Atvērt detaļas",
    "Details" : "Detaļas",
    "Sharing" : "Koplietošana",
    "Tags" : "Birkas",
    "Activity" : "Darbības",
    "Undo" : "Atsaukt",
    "Searching for users, groups and teams …" : "Meklē lietotājus, kopas un komandas …",
    "(Group)" : "(Grupa)",
    "Can edit" : "Var labot",
    "Can share" : "Var koplietot",
    "Owner" : "Īpašnieks",
    "Delete" : "Dzēst",
    "Edit" : "Labot",
    "Members" : "Biedri",
    "Download" : "Lejupielādēt",
    "File to share" : "Kopīgojamā datne",
    "Attachments" : "Pielikumi",
    "Comments" : "Piebildes",
    "Modified" : "Mainīts",
    "Created" : "Izveidots",
    "Save" : "Saglabāt",
    "Reply" : "Atbildēt",
    "Update" : "Atjaunināt",
    "Created:" : "Izveidots:",
    "Description" : "Apraksts",
    "Select Date" : "Izvēlieties datumu",
    "(group)" : "(grupa)",
    "seconds ago" : "sekundēm",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Keyboard shortcut" : "Tastatūras saīsne",
    "Action" : "Darbība",
    "Search" : "Meklēt",
    "Shared with you" : "Koplietots ar tevi",
    "No notifications" : "Nav paziņojumu",
    "No reminder" : "Nav atgādinājuma",
    "An error occurred" : "Gadījās kļūda",
    "Today" : "Šodien",
    "Tomorrow" : "Rīt",
    "Close" : "Aizvērt",
    "Share" : "Koplietot",
    "Next week" : "Nākamā nedēļa",
    "Next month" : "Nākamais mēnesis"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-app-deck-1%3A1.14.2-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/lv.js <==
OC.L10N.register(
    "deck",
    {
    "You have added a description to card {card} in list {stack} on board {board}" : "Tu pievienoji kartītes {card} aprakstu dēļa {board} sarakstā {stack}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} pievienoja kartītes {card} aprakstu dēļa {board} sarakstā {stack}",
    "Load more" : "Ielādēt vairāk",
    "Personal" : "Personīgs",
    "Finished" : "Pabeigts",
    "Later" : "Vēlāk",
    "copy" : "kopēt",
    "Done" : "Pabeigts",
    "The file was uploaded" : "Datne tika augšupielādēta",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Augšupielādētā datne pārsniedz php.ini norādīto upload_max_filesize vērtību",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Augšupielādētā datne pārsniedz MAX_FILE_SIZE norādi, kas ir norādīta HTML formā",
    "The file was only partially uploaded" : "Datne tika augšupielādēta tikai daļēji",
    "No file was uploaded" : "Neviena datne netika augšupielādēta",
    "Missing a temporary folder" : "Trūkst pagaidu mapes",
    "Could not write file to disk" : "Nevarēja ierakstīt datni diskā",
    "A PHP extension stopped the file upload" : "PHP paplašinājums apturēja datnes augšupielādi",
    "Invalid date, date format must be YYYY-MM-DD" : "Nederīgs datums, datuma formātam jābūt YYYY-MM-DD",
    "Cancel" : "Atcelt",
    "File already exists" : "Datne jau pastāv",
    "Do you want to overwrite it?" : "Vai tu gribi pārrakstīt to?",
    "Open" : "Atvērt",
    "Completed" : "Pabeigts",
    "Clear filter" : "Notīrīt atlasi",
    "Hide archived cards" : "Slēpt arhivētās kartes",
    "Show archived cards" : "Rādīt arhivētās kartes",
    "Open details" : "Atvērt detaļas",
    "Details" : "Detaļas",
    "Sharing" : "Koplietošana",
    "Tags" : "Birkas",
    "Activity" : "Darbības",
    "Undo" : "Atsaukt",
    "Searching for users, groups and teams …" : "Meklē lietotājus, kopas un komandas …",
    "(Group)" : "(Grupa)",
    "Can edit" : "Var labot",
    "Can share" : "Var koplietot",
    "Owner" : "Īpašnieks",
    "Delete" : "Dzēst",
    "Edit" : "Labot",
    "Members" : "Biedri",
    "Download" : "Lejupielādēt",
    "File to share" : "Kopīgojamā datne",
    "Attachments" : "Pielikumi",
    "Comments" : "Piebildes",
    "Modified" : "Mainīts",
    "Created" : "Izveidots",
    "Save" : "Saglabāt",
    "Reply" : "Atbildēt",
    "Update" : "Atjaunināt",
    "Created:" : "Izveidots:",
    "Description" : "Apraksts",
    "Select Date" : "Izvēlieties datumu",
    "(group)" : "(grupa)",
    "seconds ago" : "sekundēm",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Keyboard shortcut" : "Tastatūras saīsne",
    "Action" : "Darbība",
    "Search" : "Meklēt",
    "Shared with you" : "Koplietots ar tevi",
    "No notifications" : "Nav paziņojumu",
    "No reminder" : "Nav atgādinājuma",
    "An error occurred" : "Gadījās kļūda",
    "Today" : "Šodien",
    "Tomorrow" : "Rīt",
    "Close" : "Aizvērt",
    "Share" : "Koplietot"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
